<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_CN">
<context>
    <name>DecoderCUEFactory</name>
    <message>
        <location filename="../decodercuefactory.cpp" line="44"/>
        <source>CUE Plugin</source>
        <translation>CUE 插件</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="47"/>
        <source>CUE Files</source>
        <translation>CUE 文件</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="95"/>
        <source>About CUE Audio Plugin</source>
        <translation>关于 CUE 音频插件</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="96"/>
        <source>Qmmp CUE Audio Plugin</source>
        <translation>Qmmp CUE 音频插件</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="97"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>CUE Plugin Settings</source>
        <translation>CUE 插件设置</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Common settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="35"/>
        <source>Automatic file detection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>CUE encoding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="51"/>
        <source>Automatic charset detection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="61"/>
        <source>Language:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="81"/>
        <source>Default encoding:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
